@@ -1,7 +1,8 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ecos gmbh   www.ecos.de
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2014 Gerald Richter
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -30,12 +31,15 @@ __EMBPERL__
 #   show - output the control
 #]
 
-[$ sub show ($self, $data)
+[$ sub show ($self, $req)
+
+$]<table class="ef-element ef-element-width-[+ $self -> {width_percent} +] ef-element-[+ $self -> {type} || 'blank' +] [+ ' ' . $self -> {state} +]">
+  <tr>
+    <td class="ef-label-box ef-label-box-width-100">[$ if $self -> {controlclass} $]<span class="[+$self->{controlclass}+]">[+ $self->{text} +]</span>[$else$][+ $self->{text} +][$endif$]</td>
+    [#<td class="ef-control-box ef-control-box-width-100">[+ $self->{text} +]</td>#]
+  </tr>
+</table>[$endsub$]
 
-my $span = ($self->{width_percent})  ;
-$]
-<td class="cBase cLabelBox" colspan="[+ $span +]">[+ $self->{text} +]</td>
-[$endsub$]
 
 
 __END__
@@ -72,7 +76,7 @@ Could be used to give a text that should be displayed inside the blank area
 
 =head1 Author
 
-G. Richter (richter@dev.ecos.de)
+G. Richter (richter at embperl dot org)
 
 =head1 See Also
 
