@@ -1,7 +1,8 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ecos gmbh   www.ecos.de
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2014 Gerald Richter
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -17,7 +18,7 @@
 package Embperl::Form::Control::tinymce ;
 
 use strict ;
-use base 'Embperl::Form::Control' ;
+use base 'Embperl::Form::Control::textarea' ;
 
 use Embperl::Inline ;
 
@@ -30,8 +31,48 @@ __EMBPERL__
 #   show_control - output the control
 #]
 
-[$ sub show_control ($self) $]
+[$ sub show_control ($self, $req) 
 
+my $options = $self -> {tinymce} || {} ;
+foreach my $k (keys %$options)
+    {
+    my $v = $options -> {$k} ;
+    $v =~ s/\'/\"/g ;
+    $options -> {$k} = $v if ($v =~ s/%%(.+?)%%/$fdat{$1}/g) ;
+    }
+$]
+
+[- $ctrlid = $self -> SUPER::show_control ($req) ; -]
+<script>
+$('#[+ $ctrlid +]').tinymce({
+	script_url : '/_appserv/js/tiny_mce/tiny_mce.js',
+	theme : "advanced",
+	//plugins : "table,insertdatetime,searchreplace,print,contextmenu,paste,fullscreen,noneditable",
+	plugins : "insertdatetime,searchreplace,print,contextmenu,paste,fullscreen,noneditable,autoresize,inlinepopups",
+   dialog_type : "modal",
+	theme_advanced_buttons1 : "bold,italic,underline,strikethrough,styleselect,bullist,numlist,outdent,indent,undo,redo,link,unlink,image,sub,sup,charmap,insertdate,inserttime,search,replace,fullscreen",
+	theme_advanced_buttons2 : '', //"print,cut,copy,pastetext,pasteword,selectall",
+	theme_advanced_buttons3 : "",
+	theme_advanced_toolbar_location : "top",
+	theme_advanced_toolbar_align : "left",
+	theme_advanced_path : false,
+	//content_css : "example_full.css",
+	plugin_insertdate_dateFormat : "%d.%m.%Y",
+	plugin_insertdate_timeFormat : "%H:%M:%S",
+	extended_valid_elements : "hr[class|width|size|noshade],font[face|size|color|style],span[class|align|style]",
+	theme_advanced_resizing : true,
+	inline_styles : false,
+    [$ foreach my $k (keys %$options) $] 
+    [+ $k +] : '[+ $options -> {$k} +]',
+    [$endforeach$]
+	onchange_callback : function () 
+		{ 
+		$('#[+ $ctrlid +]').trigger ('input_changed') ; 
+		}
+    
+   });
+</script>
+[#
 <script language="javascript" type="text/javascript" src="/tiny_mce/tiny_mce.js"></script>
 [$ if $self -> {theme} ne 'big' $]
 <script language="javascript" type="text/javascript">
@@ -78,11 +119,8 @@ __EMBPERL__
 	});
 </script>
 [$endif$]
+#]
 
-<textarea type="text"  class="cBase cControl cMceEditor"  name="[+ $self->{name} +]"
-[$if $self -> {cols} $]cols="[+ $self->{cols} +]"[$endif$]
-[$if $self -> {rows} $]rows="[+ $self->{rows} +]"[$endif$]
-></textarea>
 [$endsub$]
 
 __END__
@@ -129,7 +167,7 @@ Number of rows
 
 =head1 Author
 
-G. Richter (richter@dev.ecos.de)
+G. Richter (richter at embperl dot org)
 
 =head1 See Also
 
