@@ -1,7 +1,8 @@
 
 ###################################################################################
 #
-#   Embperl  - Copyright (c) 1997-2010 Gerald Richter / ecos gmbh   www.ecos.de
+#   Embperl  - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl  - Copyright (c) 2008-2014 Gerald Richter
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -10,7 +11,7 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: EMail.pm 410198 2006-05-30 06:49:55Z richter $
+#   $Id: EMail.pm 1578075 2014-03-16 14:01:14Z richter $
 #
 ###################################################################################
 
@@ -79,7 +80,7 @@ sub getscript_validate
     {
     my ($self, $arg, $pref) = @_ ;
     
-    return ('((obj.value.search(/^[^ <>()@-]+@[^ <>()@-]+\.[a-zA-Z]{2,4}$/) >= 0) && (obj.value.search(/@(\.|.*(\.\.|@))|mailto:/i) < 0))', 
+    return ('((obj.value.search(/^[^ <>()@\x80-\xff]+@[^ <>()@\x80-\xff]+\.[a-zA-Z]{2,4}$/) >= 0) && (obj.value.search(/@(\.|.*(\.\.|@))|mailto:/i) < 0))', 
 	    ['validate_email', "'+obj.value+'"]) ;
     }
 
