@@ -1,7 +1,8 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ecos gmbh   www.ecos.de
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2014 Gerald Richter
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -10,7 +11,7 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: Embperl.pm 294769 2005-08-13 19:43:05Z richter $
+#   $Id: Embperl.pm 1578075 2014-03-16 14:01:14Z richter $
 #
 ###################################################################################
 
@@ -62,7 +63,7 @@ __END__
 
 =head1 NAME
 
-Embperl::Recipe::Embperl
+Embperl::Recipe::Embperl - the default Embperl recipe
 
 =head1 SYNOPSIS
 
@@ -73,7 +74,7 @@ Defines the default recipe for Embperl.
 
 =head1 Author
 
-G. Richter (richter@dev.ecos.de)
+G. Richter (richter at embperl dot org)
 
 =head1 See Also
 
