@@ -1,7 +1,8 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ECOS
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2014 Gerald Richter
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -10,7 +11,7 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: EmbperlXSLT.pm 294769 2005-08-13 19:43:05Z richter $
+#   $Id: EmbperlXSLT.pm 1578075 2014-03-16 14:01:14Z richter $
 #
 ###################################################################################
  
@@ -68,7 +69,7 @@ __END__
 
 =head1 NAME
 
-Embperl::Recipe::EmbperlXSLT
+Embperl::Recipe::EmbperlXSLT - recipe to perform an XSLT transformation last
 
 =head1 SYNOPSIS
 
@@ -79,7 +80,7 @@ This recipe does an XSLT transformation after normal Embperl processing.
 
 =head1 Author
 
-G. Richter (richter@dev.ecos.de)
+G. Richter (richter at embperl dot org)
 
 =head1 See Also
 
