@@ -1,7 +1,8 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ECOS
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2014 Gerald Richter
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -10,7 +11,7 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: Syntax.pm 294756 2005-08-07 00:03:03Z richter $
+#   $Id: Syntax.pm 1578075 2014-03-16 14:01:14Z richter $
 #
 ###################################################################################
  
@@ -325,7 +326,7 @@ sub CloneHash
             embperl => { 
                 perlcode    => q{ 
 # any initialisation could be put here
-$DB::single = 1 ;
+#$DB::single = 1 ;
 $maxrow=100;$maxcol=10;
 },
                 compiletimeperlcode => q{
@@ -395,7 +396,7 @@ __END__
 
 =head1 NAME
 
-Embperl base class for defining custom syntaxes
+Embperl::Syntax - base class for defining custom syntaxes
 
 =head1 SYNOPSIS
 
@@ -461,7 +462,7 @@ You can also specify multiple syntaxes e.g.
 
     Execute ({inputfile => '*', syntax => 'Embperl ASP'}) ;
 
-The syntax metacommand allows to switch the syntax or to 
+The syntax metacommand allows you to switch the syntax or to
 add or subtract syntaxes e.g.
 
     [$ syntax + Mail $]
@@ -524,7 +525,7 @@ Returns the root of the parser tree.
 
 Returns a syntax object which is build form the syntaxes named
 in C<$name>. If C<$oldname> is given, C<$name> can start with a C<+> or C<->
-to add or subtract a syntax. This is normaly only needed by Embperl itself
+to add or subtract a syntax. This is normally only needed by Embperl itself
 or to implement a syntax switch statement (see I<Embperl::Syntax::SSI>
 for an example.)
 
@@ -646,7 +647,7 @@ set under C<inside>. Set 2 to don't the end text. Set to 3 for both.
 
 =item 'procinfo' => 
 
-Processor info. Hashref with informations how to process this token.
+Processor info. Hashref with information how to process this token.
 
 =back
 
@@ -654,7 +655,7 @@ Processor info. Hashref with informations how to process this token.
 
 The processor info gives information how to compile this token to valid
 code that can be executed later on by the processor. There could be
-informations for multiple processors. At the moment only the I<embperl>
+information for multiple processors. At the moment only the I<embperl>
 processor is defined. Normaly you must not worry about different
 processor, because the syntax object knows inside that all procinfo is
 for the I<embperl> processor. I<procinfo> is a parameter to many methods,
@@ -770,8 +771,8 @@ The same special strings are replaced as in C<perlcode>.
 C<$_[0]> contains the Embperl request object. The method C<Code> can be used to 
 get or set the perl code that should be generated by this node.
 
-If the code begins with #!- all newlines are removed in the code. This is basicly
-usefull to keep all code on the same line, so the linenumber in error reporting
+If the code begins with #!- all newlines are removed in the code. This is basically
+useful to keep all code on the same line, so the line number in error reporting
 matches the line in the source. 
 
 =item compiletimeperlcodeend => <string>
@@ -782,8 +783,8 @@ The same special strings are replaced as in C<perlcode>.
 C<$_[0]> contains the Embperl request object. The method C<Code> can be used to 
 get or set the perl code that should be generated by this node.
 
-If the code begins with #!- all newlines are removed in the code. This is basicly
-usefull to keep all code on the same line, so the linenumber in error reporting
+If the code begins with #!- all newlines are removed in the code. This is basically
+useful to keep all code on the same line, so the linenumber in error reporting
 matches the line in the source. 
 
 =item perlcoderemove => 0/1
@@ -806,24 +807,24 @@ Remove this node only
 
 Remove next node if it consists of only white spaces and optKeepSpaces isn't set.
 
-=item 4
+=item 3
 
 Replace next node with one space if next node consists only of white spaces and
 optKeepSpaces isn't set.
 
-=item 8
+=item 4
 
 Set this node to ignore for output.
 
-=item 16
+=item 5
 
 Remove all child nodes
 
-=item 32
+=item 6
 
 Set all child nodes to ignore for output.
 
-=item 64
+=item 7
 
 Calculate Attributes values of this node also for nodes that are set to ignore for output
 (makes only sense if 8 is also set).
@@ -845,23 +846,23 @@ Remove all white spaces before tag
 
 Remove all white spaces after tag
 
-=item 4
+=item 3
 
 Remove spaces and tabs before tag
 
-=item 8
+=item 4
 
 Remove spaces and tabs after tag
 
-=item 16
+=item 5
 
 Remove all spaces and tabs but one before tag
 
-=item 32
+=item 6
 
 Remove all whihe space after text inside of tag
 
-=item 64
+=item 7
 
 Remove spaces and tabs  after text inside of tag
 
@@ -869,7 +870,7 @@ Remove spaces and tabs  after text inside of tag
 
 =item mayjump => 0/1
 
-If set,  tells the compiler that this code may jump to another programm location.
+If set, tells the compiler that this code may jump to another program location.
 (e.g. if, while, goto etc.).
 Could also be a condition as described under perlcode.
 
