@@ -1,7 +1,8 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ECOS
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2014 Gerald Richter
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -10,7 +11,7 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: EmbperlBlocks.pm 355574 2005-12-09 18:15:54Z richter $
+#   $Id: EmbperlBlocks.pm 1578075 2014-03-16 14:01:14Z richter $
 #
 ###################################################################################
  
@@ -57,7 +58,7 @@ sub new
 
         Init ($self, ref $exchange?$exchange:undef) ;
 
-        $self -> AddInitCode ('use Data::Dumper ;') ;
+        $self -> AddInitCode ('use Data::Dumper;') ;
         }
 
     return $self ;
@@ -602,7 +603,7 @@ __END__
 
 =head1 NAME
 
-Embperl::Syntax::EmbperlBlocks
+Embperl::Syntax::EmbperlBlocks - syntax for Embperl Blocks and metacommands
 
 =head1 SYNOPSIS
 
@@ -645,7 +646,7 @@ See I<Embperl::Syntax> for a definition of procinfo.
 
 =head1 Author
 
-G. Richter (richter@dev.ecos.de)
+G. Richter (richter at embperl dot org)
 
 =head1 See Also
 
