@@ -1,7 +1,8 @@
 
 /*###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ECOS
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2014 Gerald Richter
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -11,7 +12,7 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: embperl.h 1004099 2010-10-04 03:49:25Z richter $
+#   $Id: embperl.h 1578075 2014-03-16 14:01:14Z richter $
 #
 ###################################################################################*/
 
@@ -178,7 +179,8 @@ enum opt
     optDisableSelectScan       = 0x800000,
     optEnableChdir             = 0x1000000,
     optFormDataNoUtf8          = 0x2000000,
-    optShowBacktrace           = 0x8000000
+    optShowBacktrace           = 0x8000000,
+    optChdirToSource           = 0x10000000
     } ;
 
 /* --- output escaping --- */
